@@ -37,7 +37,7 @@
  *
  * If a subsystem is disabled in GStreamer, a value is defined in
  * &lt;gst/gst.h&gt;. You can check this if you do subsystem-specific stuff.
- * <example>
+ * <example id="example-gstconfig">
  * <title>Doing subsystem specific things</title>
  * <programlisting>
  * &hash;ifndef GST_DISABLE_GST_DEBUG
@@ -53,7 +53,6 @@
 /* trick gtk-doc into believing these symbols are defined (yes, it's ugly) */
 
 #if 0
-#define GST_DISABLE_LOADSAVE_REGISTRY 1
 #define GST_DISABLE_GST_DEBUG 1
 #define GST_DISABLE_LOADSAVE 1
 #define GST_DISABLE_PARSE 1
@@ -64,12 +63,14 @@
 #define GST_DISABLE_INDEX 1
 #define GST_DISABLE_PLUGIN 1
 #define GST_DISABLE_URI 1
+#define GST_DISABLE_XML 1
+#define GST_DISABLE_LOADSAVE_REGISTRY 1
 #define GST_HAVE_GLIB_2_8 1
 #endif
 
 /***** default padding of structures *****/
 #define GST_PADDING		4
-#define GST_PADDING_INIT	{0}
+#define GST_PADDING_INIT	{ NULL }
 
 /***** padding for very extensible base classes *****/
 #define GST_PADDING_LARGE	20
@@ -81,12 +82,12 @@
  *
  * Configures the inclusion of the debugging subsystem
  */
-#define GST_DISABLE_GST_DEBUG 1
+/* #undef GST_DISABLE_GST_DEBUG */
 
 /**
  * GST_DISABLE_LOADSAVE:
  *
- * Configures the inclusion of the plugin graph xml-serialisation 
+ * Configures the inclusion of the plugin graph xml-serialisation
  * (was used in 0.8 by gst-editor)
  */
 /* #undef GST_DISABLE_LOADSAVE */
@@ -117,12 +118,20 @@
 /**
  * GST_DISABLE_REGISTRY:
  *
- * Configures the use of the plugin registry
- * if one disables this, required plugins need to be loaded and registered
- * manualy
+ * Configures the use of the plugin registry.
+ * If one disables this, required plugins need to be loaded and registered
+ * manually
  */
 /* #undef GST_DISABLE_REGISTRY */
 
+/**
+ * GST_DISABLE_XML:
+ *
+ * Configures the use libxml2. This setting is derived from the settings of
+ * %GST_DISABLE_LOADSAVE and %GST_DISABLE_REGISTRY (in the xml registry case).
+ */
+/* #undef GST_DISABLE_XML */
+
 /* FIXME: test and document these! */
 /* Configure the use of glib enumtypes (useful for introspection)
  * see http://bugzilla.gnome.org/show_bug.cgi?id=342564
@@ -163,15 +172,18 @@
 /* whether or not the CPU supports unaligned access */
 #define GST_HAVE_UNALIGNED_ACCESS 0
 
-/* whether or not we are using glib 2.8 api, e.g. atomic gobject
-   refcounting */
+/* FIXME: 0.11 (remove)
+ * whether or not we are using glib 2.8 api, e.g. atomic gobject
+ * refcounting */
 #define GST_HAVE_GLIB_2_8 1
 
 /***** Deal with XML stuff, we have to handle both loadsave and registry *****/
-
-#if (! (defined(GST_DISABLE_LOADSAVE) && defined(GST_DISABLE_REGISTRY)) )
+/* FIXME: move include to where we need it */
+/*#if (! (defined(GST_DISABLE_LOADSAVE) && defined(GST_DISABLE_REGISTRY)) )*/
+#ifndef GST_DISABLE_XML
 # include <libxml/parser.h>
 #else
+  /* FIXME: 0.11 (replace by GST_DISABLE_XML) */
 # define GST_DISABLE_LOADSAVE_REGISTRY
 #endif
 
