@@ -77,9 +77,9 @@ G_BEGIN_DECLS
  * @GST_STATE_CHANGE_FAILURE   : the state change failed
  * @GST_STATE_CHANGE_SUCCESS   : the state change succeeded
  * @GST_STATE_CHANGE_ASYNC     : the state change will happen asynchronously
- * @GST_STATE_CHANGE_NO_PREROLL: the state change succeeded but the element cannot
- *                               produce data in PAUSED. This typically happens
- *                               with live sources.
+ * @GST_STATE_CHANGE_NO_PREROLL: the state change succeeded but the element
+ *                               cannot produce data in PAUSED. This typically
+ *                               happens with live sources.
  *
  * The possible return values from a state change function. Only
  * @GST_STATE_CHANGE_FAILURE is a real failure.
@@ -119,6 +119,16 @@ typedef enum {
  */
 #define GST_STATE_PENDING(elem)		(GST_ELEMENT_CAST(elem)->pending_state)
 
+/**
+ * GST_STATE_TARGET:
+ * @elem: a #GstElement to return the target state for.
+ *
+ * This macro returns the target #GstState of the element.
+ *
+ * Since: 0.10.13
+ */
+#define GST_STATE_TARGET(elem)		(GST_ELEMENT_CAST(elem)->abidata.ABI.target_state)
+
 /**
  * GST_STATE_RETURN:
  * @elem: a #GstElement to return the last state result for.
@@ -427,7 +437,14 @@ struct _GstElement
   guint32               pads_cookie;
 
   /*< private >*/
-  gpointer _gst_reserved[GST_PADDING];
+  union {
+    struct {
+      /* state set by application */
+      GstState              target_state;
+    } ABI;
+    /* adding + 0 to mark ABI change to be undone later */
+    gpointer _gst_reserved[GST_PADDING + 0];
+  } abidata;
 };
 
 /**
@@ -514,9 +531,13 @@ struct _GstElementClass
 /* element class pad templates */
 void			gst_element_class_add_pad_template	(GstElementClass *klass, GstPadTemplate *templ);
 GstPadTemplate*		gst_element_class_get_pad_template	(GstElementClass *element_class, const gchar *name);
-GList*                  gst_element_class_get_pad_template_list (GstElementClass *element_class);
-void			gst_element_class_set_details		(GstElementClass *klass,
-								 const GstElementDetails *details);
+GList*                  gst_element_class_get_pad_template_list	(GstElementClass *element_class);
+void			gst_element_class_set_details		(GstElementClass *klass, const GstElementDetails *details);
+void			gst_element_class_set_details_simple	(GstElementClass *klass,
+			                                    	 const gchar     *longname,
+			                                    	 const gchar     *classification,
+			                                    	 const gchar     *description,
+			                                         const gchar     *author);
 
 /* element instance */
 GType			gst_element_get_type		(void);
@@ -626,6 +647,8 @@ GstStateChangeReturn	gst_element_get_state		(GstElement * element,
 GstStateChangeReturn	gst_element_set_state		(GstElement *element, GstState state);
 
 void			gst_element_abort_state		(GstElement * element);
+GstStateChangeReturn    gst_element_change_state        (GstElement * element,
+		                                         GstStateChange transition);
 GstStateChangeReturn	gst_element_continue_state	(GstElement * element,
                                                          GstStateChangeReturn ret);
 void			gst_element_lost_state	        (GstElement * element);
